require 'thor'
require 'pathname'
require 'fileutils'

module SentiaGitHooks
  class Cli < Thor

    def initialize(*args)
      super

      @scripts_dir =  Pathname.new File.expand_path("../../scripts", __FILE__)
      @sentia_dir = Pathname.new("~/.sentia/").expand_path
      @sentia_hooks_dir = @sentia_dir + "git-hooks"
      @new_hooks_dir = Pathname.new(Dir.pwd) + ".git/hooks"
    end



    desc "update", "Update the git hooks on your system"
    def update
      FileUtils.mkdir_p @sentia_dir
      FileUtils.rm_f @sentia_hooks_dir
      FileUtils.ln_s @scripts_dir, @sentia_hooks_dir, force: true
    end



    desc "install", "Install sentia git hooks into the current repository"
    def install
      script_files = Dir.entries @sentia_hooks_dir
      script_files.delete(".")
      script_files.delete("..")

      script_files.each do |file|
        existing_script = @sentia_hooks_dir + file
        new_hook = File.expand_path file, @new_hooks_dir

        begin
          FileUtils.ln_s existing_script, new_hook
          exit 0
        rescue
          puts "Failed
          If a hook file already exists then we refuse to clobber it,
          you'll have to delete it manually, or have it call the functionality
          in our hook."
          exit 1
        end
      end
    end

  end
end




# scripts_dir =  Pathname.new File.expand_path("../../lib/scripts", __FILE__)
# sentia_dir = Pathname.new("~/.sentia/").expand_path
# sentia_hooks_dir = sentia_dir + "git-hooks"
# new_hooks_dir = Pathname.new(Dir.pwd) + ".git/hooks"

# FileUitels.rm_f sentia_hooks_dir
# FileUtils.ln_s scripts_dir, sentia_hooks_dir, force: true



# puts script_files



# puts "Success"
# exit 0
